import { ClientParams } from '../create-cma-http-client';
import * as endpoints from './endpoints';
import { DefaultParams } from './wrappers/wrap';
export declare const createPlainClient: (params: ClientParams, defaults?: DefaultParams | undefined) => {
    editorInterface: {
        get: (params: Pick<endpoints.editorInterface.GetEditorInterfaceParams, "contentTypeId"> & Partial<Pick<endpoints.editorInterface.GetEditorInterfaceParams, "spaceId" | "environmentId">>) => Promise<import("../entities/editor-interface").EditorInterfaceProps>;
        update: (params: Pick<endpoints.editorInterface.GetEditorInterfaceParams, "contentTypeId"> & Partial<Pick<endpoints.editorInterface.GetEditorInterfaceParams, "spaceId" | "environmentId">>, rawData: import("../entities/editor-interface").EditorInterfaceProps, headers?: Record<string, unknown> | undefined) => Promise<import("../entities/environment").EnvironmentProps>;
    };
    organization: {
        getAll: () => Promise<import("../common-types").CollectionProp<import("../entities/organization").OrganizationProp>>;
    };
    space: {
        get: (params: Pick<endpoints.space.GetSpaceParams, never> & Partial<Pick<endpoints.space.GetSpaceParams, "spaceId">>) => Promise<import("../entities/space").SpaceProps>;
        update: (params: Pick<endpoints.space.GetSpaceParams, never> & Partial<Pick<endpoints.space.GetSpaceParams, "spaceId">>, rawData: import("../entities/space").SpaceProps, headers?: Record<string, unknown> | undefined) => Promise<import("../entities/space").SpaceProps>;
        delete: (params: Pick<endpoints.space.GetSpaceParams, never> & Partial<Pick<endpoints.space.GetSpaceParams, "spaceId">>) => Promise<any>;
    };
    environment: {
        get: (params: Pick<endpoints.environment.GetEnvironmentParams, never> & Partial<Pick<endpoints.environment.GetEnvironmentParams, "spaceId" | "environmentId">>) => Promise<import("../entities/environment").EnvironmentProps>;
        getMany: (params: Pick<endpoints.space.GetSpaceParams & import("./endpoints/common-types").PaginationQueryParams, "query"> & Partial<Pick<endpoints.space.GetSpaceParams & import("./endpoints/common-types").PaginationQueryParams, "spaceId">>) => Promise<import("../common-types").CollectionProp<import("../entities/environment").EnvironmentProps>>;
        create: (params: Pick<endpoints.space.GetSpaceParams, never> & Partial<Pick<endpoints.space.GetSpaceParams, "spaceId">>, rawData: Partial<Pick<import("../entities/environment").EnvironmentProps, "name">>, headers?: Record<string, unknown> | undefined) => Promise<import("../entities/environment").EnvironmentProps>;
        createWithId: (params: Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            sourceEnvironmentId?: string | undefined;
        }, "sourceEnvironmentId"> & Partial<Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            sourceEnvironmentId?: string | undefined;
        }, "spaceId" | "environmentId">>, rawData: Partial<Pick<import("../entities/environment").EnvironmentProps, "name">>, headers?: Record<string, unknown> | undefined) => Promise<import("../entities/environment").EnvironmentProps>;
        update: (params: Pick<endpoints.environment.GetEnvironmentParams, never> & Partial<Pick<endpoints.environment.GetEnvironmentParams, "spaceId" | "environmentId">>, rawData: import("../entities/environment").EnvironmentProps, headers?: Record<string, unknown> | undefined) => Promise<import("../entities/environment").EnvironmentProps>;
        delete: (params: Pick<endpoints.environment.GetEnvironmentParams, never> & Partial<Pick<endpoints.environment.GetEnvironmentParams, "spaceId" | "environmentId">>) => Promise<any>;
    };
    contentType: {
        getMany: (params: Pick<endpoints.contentType.GetManyContentTypesParams, "query"> & Partial<Pick<endpoints.contentType.GetManyContentTypesParams, "spaceId" | "environmentId">>) => Promise<import("../common-types").CollectionProp<import("../entities/content-type").ContentTypeProps>>;
    };
    user: {
        getManyForSpace: (params: Pick<endpoints.user.GetManyUsersParams, "query"> & Partial<Pick<endpoints.user.GetManyUsersParams, "spaceId">>) => Promise<import("../common-types").CollectionProp<import("../entities/user").UserProps>>;
        getCurrent: () => Promise<import("../entities/user").UserProps>;
    };
    entry: {
        getMany: <T extends Record<string, any> = Record<string, any>>(params: Pick<endpoints.contentType.GetManyContentTypesParams, "query"> & Partial<Pick<endpoints.contentType.GetManyContentTypesParams, "spaceId" | "environmentId">>) => Promise<import("../common-types").CollectionProp<import("../entities/entry").EntryProps<T>>>;
        get: <T_1 extends Record<string, any> = Record<string, any>>(params: Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            entryId: string;
        } & import("./endpoints/common-types").QueryParams, "query" | "entryId"> & Partial<Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            entryId: string;
        } & import("./endpoints/common-types").QueryParams, "spaceId" | "environmentId">>) => Promise<import("../entities/entry").EntryProps<T_1>>;
        update: <T_2 extends Record<string, any> = Record<string, any>>(params: Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            entryId: string;
        }, "entryId"> & Partial<Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            entryId: string;
        }, "spaceId" | "environmentId">>, rawData: import("../entities/entry").EntryProps<T_2>, headers?: Record<string, unknown> | undefined) => Promise<import("../entities/entry").EntryProps<T_2>>;
        delete: (params: Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            entryId: string;
        }, "entryId"> & Partial<Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            entryId: string;
        }, "spaceId" | "environmentId">>) => Promise<any>;
        publish: <T_3 extends Record<string, any> = Record<string, any>>(params: Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            entryId: string;
        }, "entryId"> & Partial<Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            entryId: string;
        }, "spaceId" | "environmentId">>, rawData: import("../entities/entry").EntryProps<T_3>) => Promise<import("../entities/entry").EntryProps<T_3>>;
        unpublish: <T_4 extends Record<string, any> = Record<string, any>>(params: Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            entryId: string;
        }, "entryId"> & Partial<Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            entryId: string;
        }, "spaceId" | "environmentId">>) => Promise<import("../entities/entry").EntryProps<T_4>>;
        archive: <T_5 extends Record<string, any> = Record<string, any>>(params: Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            entryId: string;
        }, "entryId"> & Partial<Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            entryId: string;
        }, "spaceId" | "environmentId">>) => Promise<import("../entities/entry").EntryProps<T_5>>;
        unarchive: <T_6 extends Record<string, any> = Record<string, any>>(params: Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            entryId: string;
        }, "entryId"> & Partial<Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            entryId: string;
        }, "spaceId" | "environmentId">>) => Promise<import("../entities/entry").EntryProps<T_6>>;
        create: <T_7 extends Record<string, any> = Record<string, any>>(params: Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            contentTypeId: string;
        }, "contentTypeId"> & Partial<Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            contentTypeId: string;
        }, "spaceId" | "environmentId">>, rawData: Pick<import("../entities/entry").EntryProps<T_7>, "fields">) => Promise<import("../entities/entry").EntryProps<T_7>>;
        createWithId: <T_8 extends Record<string, any> = Record<string, any>>(params: Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            entryId: string;
            contentTypeId: string;
        }, "contentTypeId" | "entryId"> & Partial<Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            entryId: string;
            contentTypeId: string;
        }, "spaceId" | "environmentId">>, rawData: Pick<import("../entities/entry").EntryProps<T_8>, "fields">) => Promise<import("../entities/entry").EntryProps<T_8>>;
    };
    asset: {
        getMany: (params: Pick<endpoints.contentType.GetManyContentTypesParams, "query"> & Partial<Pick<endpoints.contentType.GetManyContentTypesParams, "spaceId" | "environmentId">>) => Promise<import("../common-types").CollectionProp<import("../entities/asset").AssetProps>>;
        get: (params: Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            assetId: string;
        } & import("./endpoints/common-types").QueryParams, "query" | "assetId"> & Partial<Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            assetId: string;
        } & import("./endpoints/common-types").QueryParams, "spaceId" | "environmentId">>) => Promise<import("../entities/asset").AssetProps>;
        update: (params: Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            assetId: string;
        }, "assetId"> & Partial<Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            assetId: string;
        }, "spaceId" | "environmentId">>, rawData: import("../entities/asset").AssetProps, headers?: Record<string, unknown> | undefined) => Promise<import("../entities/asset").AssetProps>;
        delete: (params: Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            assetId: string;
        }, "assetId"> & Partial<Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            assetId: string;
        }, "spaceId" | "environmentId">>) => Promise<any>;
        publish: (params: Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            assetId: string;
        }, "assetId"> & Partial<Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            assetId: string;
        }, "spaceId" | "environmentId">>, rawData: import("../entities/asset").AssetProps) => Promise<import("../entities/asset").AssetProps>;
        unpublish: (params: Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            assetId: string;
        }, "assetId"> & Partial<Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            assetId: string;
        }, "spaceId" | "environmentId">>) => Promise<import("../entities/asset").AssetProps>;
        archive: (params: Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            assetId: string;
        }, "assetId"> & Partial<Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            assetId: string;
        }, "spaceId" | "environmentId">>) => Promise<import("../entities/asset").AssetProps>;
        unarchive: (params: Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            assetId: string;
        }, "assetId"> & Partial<Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            assetId: string;
        }, "spaceId" | "environmentId">>) => Promise<import("../entities/asset").AssetProps>;
        create: (params: Pick<endpoints.environment.GetEnvironmentParams, never> & Partial<Pick<endpoints.environment.GetEnvironmentParams, "spaceId" | "environmentId">>, rawData: Pick<import("../entities/asset").AssetProps, "fields">) => Promise<import("../entities/asset").AssetProps>;
        createWithId: (params: Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            assetId: string;
        }, "assetId"> & Partial<Pick<endpoints.space.GetSpaceParams & {
            environmentId: string;
        } & {
            assetId: string;
        }, "spaceId" | "environmentId">>, rawData: Pick<import("../entities/asset").AssetProps, "fields">) => Promise<import("../entities/asset").AssetProps>;
    };
    locale: {
        getMany: (params: Pick<endpoints.contentType.GetManyContentTypesParams, "query"> & Partial<Pick<endpoints.contentType.GetManyContentTypesParams, "spaceId" | "environmentId">>) => Promise<import("../common-types").CollectionProp<import("../entities/locale").LocaleProps>>;
    };
    raw: {
        getDefaultParams: () => DefaultParams | undefined;
        get: (url: string, config?: import("axios").AxiosRequestConfig | undefined) => Promise<any>;
        post: (url: string, payload?: any, config?: import("axios").AxiosRequestConfig | undefined) => Promise<any>;
        put: (url: string, payload?: any, config?: import("axios").AxiosRequestConfig | undefined) => Promise<any>;
        delete: (url: string, config?: import("axios").AxiosRequestConfig | undefined) => Promise<any>;
    };
};
